/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the TI Explorer Lisp Machine
 * keyboard.
 */

static const KeyCode explorer_codes [] = {
  /* Row 0 */
  8,
  15, 16, 17, 18,
  10, 11, 12, 13,
  20, 21, 22, 23,
  24, 25, 26,
  27, 28, 29, 30,
  
  /* Row 2 */
  40,
  42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56,
  57, 58, 59, 60,
  
  /* Row 3 */
  61,
  63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75,
  77,
  78,
  79, 80, 81, 82,

  /* Row 4 */
  83,
  86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
  100, 101, 102,
  103, 104, 105, 106,

  /* Row 5 */
  109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 123,
  124,
  125, 126, 127, 134,
  
  /* Row 6 */
  14, 33,
  34, 35, 130, 36, 37, 38, 39,
  132, 133
};
